@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -20,6 +20,7 @@ import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.nio.charset.StandardCharsets;
+import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
@@ -81,8 +82,6 @@ import org.w3c.dom.Element;
 import org.xml.sax.SAXException;
 import org.xml.sax.helpers.DefaultHandler;
 
-import com.ibm.icu.text.MessageFormat;
-
 /**
  * There is one instance of the debug plug-in available from
  * <code>DebugPlugin.getDefault()</code>. The debug plug-in provides:
@@ -276,26 +275,48 @@ public class DebugPlugin extends Plugin {
 	 */
 	public static final String ATTR_LAUNCH_TIMESTAMP = PI_DEBUG_CORE + ".launch.timestamp";  //$NON-NLS-1$
 
-    /**
-     * This launch attribute designates the encoding to be used by the console
-     * associated with the launch.
-     * <p>
-     * For release 3.3, the system encoding is used when unspecified. Since 3.4,
-     * the inherited encoding is used when unspecified. See {@link ILaunchManager} for a
-     * description in <code>getEncoding(ILaunchConfiguration)</code>.
-     * </p>
-     * <p>
-     * Value of this constant is the same as the value of the old
-     * <code>IDebugUIConstants.ATTR_CONSOLE_ENCODING</code> constant for backward
-     * compatibility.
-     * </p>
-     * @since 3.3
-     */
+	/**
+	 * The launch attribute that stores the time stamp of when a launch configuration was
+	 * launched. Value is {@link Long#toString(long)} of {@link System#currentTimeMillis()}.
+	 *
+	 * @since 3.15
+	 */
+	public static final String ATTR_TERMINATE_TIMESTAMP = PI_DEBUG_CORE + ".terminate.timestamp"; //$NON-NLS-1$
+
+	/**
+	 * This launch attribute designates the encoding to be used by the console
+	 * associated with the launch.
+	 * <p>
+	 * For release 3.3, the system encoding is used when unspecified. Since 3.4,
+	 * the inherited encoding is used when unspecified. See {@link ILaunchManager} for a
+	 * description in <code>getEncoding(ILaunchConfiguration)</code>.
+	 * </p>
+	 * <p>
+	 * Value of this constant is the same as the value of the old
+	 * <code>IDebugUIConstants.ATTR_CONSOLE_ENCODING</code> constant for backward
+	 * compatibility.
+	 * </p>
+	 * @since 3.3
+	 */
 	public static final String ATTR_CONSOLE_ENCODING = "org.eclipse.debug.ui.ATTR_CONSOLE_ENCODING"; //$NON-NLS-1$
 
 	/**
-	 * Boolean preference key (value <code>org.eclipse.debug.core.PREF_DELETE_CONFIGS_ON_PROJECT_DELETE</code>) that controls
-	 * whether to delete associated configurations when a project is deleted. Default value is <code>false</code>.
+	 * Launch configuration attribute - a boolean value indicating whether a
+	 * configuration should be launched with merged error and standard output.
+	 * Merging output can ensure the process output appears in console in same
+	 * order as the process produce it. On the other hand the error output can
+	 * not be colored different from standard output anymore. Default value is
+	 * <code>false</code>.
+	 *
+	 * @since 3.14
+	 */
+	public static final String ATTR_MERGE_OUTPUT = PI_DEBUG_CORE + ".ATTR_MERGE_OUTPUT"; //$NON-NLS-1$
+
+	/**
+	 * Boolean preference key (value
+	 * <code>org.eclipse.debug.core.PREF_DELETE_CONFIGS_ON_PROJECT_DELETE</code>)
+	 * that controls whether to delete associated configurations when a project
+	 * is deleted. Default value is <code>false</code>.
 	 *
 	 * @since 3.7
 	 */
@@ -334,6 +355,21 @@ public class DebugPlugin extends Plugin {
 	 */
 	public static final String ATTR_PATH = PI_DEBUG_CORE + ".ATTR_PATH"; //$NON-NLS-1$
 
+	/**
+	 * Launch configuration attribute that designates whether or not the
+	 * descendants of the {@link IProcess} associated to a launch of this
+	 * configuration should be terminated if the main-process is terminated. The
+	 * descendants (also called child- or sub-processes) of a operating system
+	 * process are the processes started by that process.
+	 *
+	 * Value is a string representing a boolean - <code>true</code> or
+	 * <code>false</code>. When unspecified, the default value is considered
+	 * <code>true</code>.
+	 *
+	 * @since 3.18
+	 */
+	public static final String ATTR_TERMINATE_DESCENDANTS = PI_DEBUG_CORE + ".TERMINATE_DESCENDANTS"; //$NON-NLS-1$
+
 	/**
 	 * The singleton debug plug-in instance.
 	 */
@@ -419,43 +455,43 @@ public class DebugPlugin extends Plugin {
 		EventNotifier fNotifier = new EventNotifier();
 		AsynchRunner fRunner = new AsynchRunner();
 
-	    /**
-         * Creates a new event dispatch job.
-         */
-        public EventDispatchJob() {
-            super(DebugCoreMessages.DebugPlugin_1);
-            setPriority(Job.INTERACTIVE);
-            setSystem(true);
-        }
+		/**
+		 * Creates a new event dispatch job.
+		 */
+		public EventDispatchJob() {
+			super(DebugCoreMessages.DebugPlugin_1);
+			setPriority(Job.INTERACTIVE);
+			setSystem(true);
+		}
 
-        @Override
+		@Override
 		protected IStatus run(IProgressMonitor monitor) {
 
-            while (!fEventQueue.isEmpty()) {
-                Object next = null;
-	            synchronized (fEventQueue) {
-	                if (!fEventQueue.isEmpty()) {
-	                	next = fEventQueue.remove(0);
-	                }
-	            }
-	            if (next instanceof Runnable) {
-	            	fRunner.async((Runnable) next);
-	            } else if (next != null) {
-	                fNotifier.dispatch((DebugEvent[]) next);
-	            }
-            }
-            return Status.OK_STATUS;
-        }
+			while (!fEventQueue.isEmpty()) {
+				Object next = null;
+				synchronized (fEventQueue) {
+					if (!fEventQueue.isEmpty()) {
+						next = fEventQueue.remove(0);
+					}
+				}
+				if (next instanceof Runnable) {
+					fRunner.async((Runnable) next);
+				} else if (next != null) {
+					fNotifier.dispatch((DebugEvent[]) next);
+				}
+			}
+			return Status.OK_STATUS;
+		}
 
-        @Override
+		@Override
 		public boolean shouldRun() {
-            return shouldSchedule();
-        }
+			return shouldSchedule();
+		}
 
-        @Override
+		@Override
 		public boolean shouldSchedule() {
-            return !(isShuttingDown() || fEventListeners.isEmpty());
-        }
+			return !(isShuttingDown() || fEventListeners.isEmpty());
+		}
 
 	}
 
@@ -570,6 +606,9 @@ public class DebugPlugin extends Plugin {
 	public synchronized ILaunchManager getLaunchManager() {
 		if (fLaunchManager == null) {
 			fLaunchManager = new LaunchManager();
+			fLaunchManager.getAllLaunchConfigurations();
+			// monitor launch configuration renames for launch groups
+			fLaunchManager.addLaunchConfigurationListener(new GroupMemberChangeListener());
 		}
 		return fLaunchManager;
 	}
@@ -662,7 +701,7 @@ public class DebugPlugin extends Plugin {
 			}
 
 			fEventListeners.clear();
-            fEventFilters.clear();
+			fEventFilters.clear();
 
 			SourceLookupUtils.shutdown();
 			Preferences.savePreferences(DebugPlugin.getUniqueIdentifier());
@@ -705,9 +744,6 @@ public class DebugPlugin extends Plugin {
 		manager.registerAdapters(actionFactory, ILaunch.class);
 		manager.registerAdapters(actionFactory, IProcess.class);
 		manager.registerAdapters(actionFactory, IDebugElement.class);
-
-		// monitor launch configuration renames for launch groups
-		getLaunchManager().addLaunchConfigurationListener(new GroupMemberChangeListener());
 	}
 
 	/**
@@ -796,37 +832,37 @@ public class DebugPlugin extends Plugin {
 		return LogicalStructureManager.getDefault().getLogicalStructureTypes(value);
 	}
 
-    /**
-     * Returns the default logical structure type among the given combination of
-     * logical structure types, or <code>null</code> if none. When the given combination
-     * of logical structure type is applicable for a value, the default logical structure
-     * type is used to display a value.
-     *
-     * @param types a combination of structures applicable to a value
-     * @return the default structure that should be used to display the value
-     * or <code>null</code> if none
-     *
-     * @since 3.1
-     */
-    public static ILogicalStructureType getDefaultStructureType(ILogicalStructureType[] types) {
-        return LogicalStructureManager.getDefault().getSelectedStructureType(types);
-    }
+	/**
+	 * Returns the default logical structure type among the given combination of
+	 * logical structure types, or <code>null</code> if none. When the given combination
+	 * of logical structure type is applicable for a value, the default logical structure
+	 * type is used to display a value.
+	 *
+	 * @param types a combination of structures applicable to a value
+	 * @return the default structure that should be used to display the value
+	 * or <code>null</code> if none
+	 *
+	 * @since 3.1
+	 */
+	public static ILogicalStructureType getDefaultStructureType(ILogicalStructureType[] types) {
+		return LogicalStructureManager.getDefault().getSelectedStructureType(types);
+	}
 
-    /**
-     * Sets the default logical structure type among the given combination of logical structure
-     * types. The logical structure types provided should all be applicable to a single
-     * value. Specifying <code>null</code> indicates there is no default logical structure
-     * for the given combination of types.
-     *
-     * @param types a combination of logical structure types applicable to a value
-     * @param def the default logical structure among the given combination of types
-     * or <code>null</code> if none
-     *
-     * @since 3.1
-     */
-    public static void setDefaultStructureType(ILogicalStructureType[] types, ILogicalStructureType def) {
-        LogicalStructureManager.getDefault().setEnabledType(types, def);
-    }
+	/**
+	 * Sets the default logical structure type among the given combination of logical structure
+	 * types. The logical structure types provided should all be applicable to a single
+	 * value. Specifying <code>null</code> indicates there is no default logical structure
+	 * for the given combination of types.
+	 *
+	 * @param types a combination of logical structure types applicable to a value
+	 * @param def the default logical structure among the given combination of types
+	 * or <code>null</code> if none
+	 *
+	 * @since 3.1
+	 */
+	public static void setDefaultStructureType(ILogicalStructureType[] types, ILogicalStructureType def) {
+		LogicalStructureManager.getDefault().setEnabledType(types, def);
+	}
 
 	/**
 	 * Convenience method that performs a runtime exec on the given command line
@@ -868,16 +904,62 @@ public class DebugPlugin extends Plugin {
 	 * @since 3.0
 	 */
 	public static Process exec(String[] cmdLine, File workingDirectory, String[] envp) throws CoreException {
-		Process p= null;
+		return exec(cmdLine, workingDirectory, envp, false);
+	}
+
+	/**
+	 * Convenience method that performs a runtime exec on the given command line
+	 * in the context of the specified working directory, and returns the
+	 * resulting process. If the current runtime does not support the
+	 * specification of a working directory, the status handler for error code
+	 * <code>ERR_WORKING_DIRECTORY_NOT_SUPPORTED</code> is queried to see if the
+	 * exec should be re-executed without specifying a working directory.
+	 *
+	 * @param cmdLine the command line
+	 * @param workingDirectory the working directory, or <code>null</code>
+	 * @param envp the environment variables set in the process, or
+	 *            <code>null</code>
+	 * @param mergeOutput if <code>true</code> the error stream will be merged
+	 *            with standard output stream and both can be read through the
+	 *            same output stream
+	 * @return the resulting process or <code>null</code> if the exec is
+	 *         canceled
+	 * @exception CoreException if the exec fails
+	 * @see Runtime
+	 *
+	 * @since 3.14
+	 */
+	public static Process exec(String[] cmdLine, File workingDirectory, String[] envp, boolean mergeOutput) throws CoreException {
+		Process p = null;
 		try {
-			if (workingDirectory == null) {
-				p= Runtime.getRuntime().exec(cmdLine, envp);
+			// starting with and without merged output could be done with the
+			// same process builder approach but since the handling of
+			// environment variables is slightly different between
+			// ProcessBuilder and Runtime.exec only the new option uses process
+			// builder to not break existing caller of this method
+			if (mergeOutput) {
+				ProcessBuilder pb = new ProcessBuilder(cmdLine);
+				pb.directory(workingDirectory);
+				pb.redirectErrorStream(mergeOutput);
+				if (envp != null) {
+					Map<String, String> env = pb.environment();
+					env.clear();
+					for (String e : envp) {
+						int index = e.indexOf('=');
+						if (index != -1) {
+							env.put(e.substring(0, index), e.substring(index + 1));
+						}
+					}
+				}
+				p = pb.start();
+			} else if (workingDirectory == null) {
+				p = Runtime.getRuntime().exec(cmdLine, envp);
 			} else {
-				p= Runtime.getRuntime().exec(cmdLine, envp, workingDirectory);
+				p = Runtime.getRuntime().exec(cmdLine, envp, workingDirectory);
 			}
 		} catch (IOException e) {
-		    Status status = new Status(IStatus.ERROR, getUniqueIdentifier(), ERROR, DebugCoreMessages.DebugPlugin_0, e);
-		    throw new CoreException(status);
+			Status status = new Status(IStatus.ERROR, getUniqueIdentifier(), ERROR, DebugCoreMessages.DebugPlugin_0, e);
+			throw new CoreException(status);
 		} catch (NoSuchMethodError e) {
 			//attempting launches on 1.2.* - no ability to set working directory
 			IStatus status = new Status(IStatus.ERROR, getUniqueIdentifier(), ERR_WORKING_DIRECTORY_NOT_SUPPORTED, DebugCoreMessages.DebugPlugin_Eclipse_runtime_does_not_support_working_directory_2, e);
@@ -885,8 +967,8 @@ public class DebugPlugin extends Plugin {
 
 			if (handler != null) {
 				Object result = handler.handleStatus(status, null);
-				if (result instanceof Boolean && ((Boolean)result).booleanValue()) {
-					p= exec(cmdLine, null);
+				if (result instanceof Boolean && ((Boolean) result).booleanValue()) {
+					p = exec(cmdLine, null);
 				}
 			}
 		}
@@ -993,8 +1075,7 @@ public class DebugPlugin extends Plugin {
 		IExtensionPoint extensionPoint = Platform.getExtensionRegistry().getExtensionPoint(DebugPlugin.PI_DEBUG_CORE, EXTENSION_POINT_STATUS_HANDLERS);
 		IConfigurationElement[] infos= extensionPoint.getConfigurationElements();
 		fStatusHandlers = new HashMap<>(infos.length);
-		for (int i= 0; i < infos.length; i++) {
-			IConfigurationElement configurationElement = infos[i];
+		for (IConfigurationElement configurationElement : infos) {
 			String id = configurationElement.getAttribute("plugin"); //$NON-NLS-1$
 			String code = configurationElement.getAttribute("code"); //$NON-NLS-1$
 
@@ -1021,17 +1102,16 @@ public class DebugPlugin extends Plugin {
 		IExtensionPoint extensionPoint = Platform.getExtensionRegistry().getExtensionPoint(DebugPlugin.PI_DEBUG_CORE, EXTENSION_POINT_PROCESS_FACTORIES);
 		IConfigurationElement[] infos= extensionPoint.getConfigurationElements();
 		fProcessFactories = new HashMap<>(infos.length);
-		for (int i= 0; i < infos.length; i++) {
-			IConfigurationElement configurationElement = infos[i];
+		for (IConfigurationElement configurationElement : infos) {
 			String id = configurationElement.getAttribute("id"); //$NON-NLS-1$
 			String clss = configurationElement.getAttribute("class"); //$NON-NLS-1$
 			if (id != null && clss != null) {
-					fProcessFactories.put(id, configurationElement);
+				fProcessFactories.put(id, configurationElement);
 			} else {
 				// invalid process factory
-				String badDefiner= infos[i].getContributor().getName();
+				String badDefiner = configurationElement.getContributor().getName();
 				log(new Status(IStatus.ERROR, DebugPlugin.PI_DEBUG_CORE, ERROR, MessageFormat.format(DebugCoreMessages.DebugPlugin_4, new Object[] {
-						badDefiner, id }), null));
+					badDefiner, id }), null));
 			}
 		}
 	}
@@ -1159,13 +1239,13 @@ public class DebugPlugin extends Plugin {
 
 			fMode = NOTIFY_EVENTS;
 			if (DebugOptions.DEBUG_EVENTS) {
-				for (int i = 0; i < fEvents.length; i++) {
-					DebugOptions.trace(fEvents[i].toString());
+				for (DebugEvent event : fEvents) {
+					DebugOptions.trace(event.toString());
 				}
 			}
 			for (IDebugEventSetListener iDebugEventSetListener : fEventListeners) {
 				fListener = iDebugEventSetListener;
-                SafeRunner.run(this);
+				SafeRunner.run(this);
 			}
 			fEvents = null;
 			fFilter = null;
@@ -1236,9 +1316,9 @@ public class DebugPlugin extends Plugin {
 			abort("Unable to parse XML document.", e);  //$NON-NLS-1$
 		} finally {
 			try{
-                if (stream != null) {
-                    stream.close();
-                }
+				if (stream != null) {
+					stream.close();
+				}
 			} catch(IOException e) {
 				abort("Unable to parse XML document.", e);  //$NON-NLS-1$
 			}
@@ -1541,8 +1621,7 @@ public class DebugPlugin extends Plugin {
 
 			boolean containsSpace = false;
 			char[] characters = arguments[i].toCharArray();
-			for (int j = 0; j < characters.length; j++) {
-				char ch = characters[j];
+			for (char ch : characters) {
 				if (ch == ' ' || ch == '\t') {
 					containsSpace = true;
 					buf.append('"');
@@ -1574,6 +1653,8 @@ public class DebugPlugin extends Plugin {
 					} else {
 						buf.append('\\');
 					}
+				} else if (isWin32) {
+					backslashes = 0;
 				}
 				buf.append(ch);
 			}
@@ -1651,25 +1732,25 @@ public class DebugPlugin extends Plugin {
 	 * @since 3.4
 	 */
 	public static Object getAdapter(Object element, Class<?> type) {
-    	Object adapter = null;
-    	if (element != null) {
-	    	if (type.isInstance(element)) {
+		Object adapter = null;
+		if (element != null) {
+			if (type.isInstance(element)) {
 				return element;
 			} else {
 				if (element instanceof IAdaptable) {
-				    adapter = ((IAdaptable)element).getAdapter(type);
+					adapter = ((IAdaptable)element).getAdapter(type);
 				}
 				// for objects that don't subclass PlatformObject, check the platform's adapter manager
 				if (adapter == null && !(element instanceof PlatformObject)) {
-	                adapter = Platform.getAdapterManager().getAdapter(element, type);
+					adapter = Platform.getAdapterManager().getAdapter(element, type);
 				}
 				// force load the adapter in case it really is available
 				if (adapter == null) {
 					adapter = Platform.getAdapterManager().loadAdapter(element, type.getName());
 				}
 			}
-    	}
-    	return adapter;
+		}
+		return adapter;
 	}
 
 }
