@@ -13,37 +13,19 @@
  *******************************************************************************/
 package org.eclipse.debug.tests;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
 import org.eclipse.debug.tests.viewer.model.JFaceViewerPerformanceTests;
 import org.eclipse.debug.tests.viewer.model.VirtualViewerPerformanceTests;
+import org.junit.runner.RunWith;
+import org.junit.runners.Suite;
 
 /**
  * Tests for release builds.
  *
  * @since 3.6
  */
-public class PerformanceSuite extends TestSuite {
-
-    /**
-     * Returns the suite.  This is required to use the JUnit Launcher.
-     *
-     * @return the test suite
-     */
-    public static Test suite() {
-        return new PerformanceSuite();
-    }
-
-    /**
-     * Constructs the automated test suite. Adds all tests.
-     */
-    public PerformanceSuite() {
-        // JFace viewer tests
-        addTest(new TestSuite(JFaceViewerPerformanceTests.class));
-
-        // Virtual viewer tests
-        addTest(new TestSuite(VirtualViewerPerformanceTests.class));
-    }
-
+@RunWith(Suite.class)
+@Suite.SuiteClasses({
+		JFaceViewerPerformanceTests.class,
+		VirtualViewerPerformanceTests.class })
+public class PerformanceSuite {
 }
