@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -101,7 +101,7 @@ public class LaunchConfigurationTests extends AbstractLaunchTest implements ILau
 	 * Class to hold resource description infos
 	 * @since 3.9.0
 	 */
-	class ResourceItem {
+	static class ResourceItem {
 		public ResourceItem(String path, Integer type) {
 			this.path = path;
 			this.type = type;
@@ -110,7 +110,7 @@ public class LaunchConfigurationTests extends AbstractLaunchTest implements ILau
 		Integer type;
 	}
 
-	class Listener implements ILaunchConfigurationListener {
+	static class Listener implements ILaunchConfigurationListener {
 
 		private final List<ILaunchConfiguration> addedList = new ArrayList<>();
 		private final List<ILaunchConfiguration> removedList = new ArrayList<>();
@@ -1873,4 +1873,36 @@ public class LaunchConfigurationTests extends AbstractLaunchTest implements ILau
 		assertTrue(t2.isPrototype());
 	}
 
+	@Test
+	public void testNewInstanceNotifiesListener() throws CoreException {
+		ILaunchManager launchManager = DebugPlugin.getDefault().getLaunchManager();
+		final ArrayList<String> added = new ArrayList<>();
+		ILaunchConfigurationListener listener = new ILaunchConfigurationListener() {
+
+			@Override
+			public void launchConfigurationRemoved(ILaunchConfiguration configuration) {
+
+			}
+
+			@Override
+			public void launchConfigurationChanged(ILaunchConfiguration configuration) {
+
+			}
+
+			@Override
+			public void launchConfigurationAdded(ILaunchConfiguration configuration) {
+				added.add("Launch Configuration added");
+
+			}
+		};
+		launchManager.addLaunchConfigurationListener(listener);
+		String typeId = "org.eclipse.ui.externaltools.ProgramLaunchConfigurationType";
+
+		ILaunchConfigurationType type = launchManager.getLaunchConfigurationType(typeId);
+		type.newInstance(null, "new-lc").doSave();
+		assertEquals(1, added.size());
+		assertEquals("Launch Configuration added", added.get(0));
+
+	}
+
 }
