@@ -93,11 +93,9 @@ public class DelegatingModelPresentation implements IDebugModelPresentation, IDe
 		IExtensionPoint point= Platform.getExtensionRegistry().getExtensionPoint(DebugUIPlugin.getUniqueIdentifier(), IDebugUIConstants.ID_DEBUG_MODEL_PRESENTATION);
 		if (point != null) {
 			IExtension[] extensions= point.getExtensions();
-			for (int i= 0; i < extensions.length; i++) {
-				IExtension extension= extensions[i];
+			for (IExtension extension : extensions) {
 				IConfigurationElement[] configElements= extension.getConfigurationElements();
-				for (int j= 0; j < configElements.length; j++) {
-					IConfigurationElement elt= configElements[j];
+				for (IConfigurationElement elt : configElements) {
 					String id= elt.getAttribute("id"); //$NON-NLS-1$
 					if (id != null) {
 						IDebugModelPresentation lp= new LazyModelPresentation(this, elt);
@@ -146,14 +144,14 @@ public class DelegatingModelPresentation implements IDebugModelPresentation, IDe
 		return getDefaultImage(item);
 	}
 
-    @Override
+	@Override
 	public String getText(Object item) {
-    	IDebugModelPresentation lp= getConfiguredPresentation(item);
-    	if (lp != null) {
-    		return lp.getText(item);
-    	}
-    	return getDefaultText(item);
-    }
+		IDebugModelPresentation lp= getConfiguredPresentation(item);
+		if (lp != null) {
+			return lp.getText(item);
+		}
+		return getDefaultText(item);
+	}
 
 	@Override
 	public IEditorInput getEditorInput(Object item) {
@@ -319,35 +317,35 @@ public class DelegatingModelPresentation implements IDebugModelPresentation, IDe
 		return fLabelProviders;
 	}
 
-    @Override
+	@Override
 	public Color getForeground(Object element) {
-        IDebugModelPresentation presentation = getConfiguredPresentation(element);
-        if (presentation instanceof IColorProvider) {
-            IColorProvider colorProvider = (IColorProvider) presentation;
-            return colorProvider.getForeground(element);
-        }
-        return null;
-    }
+		IDebugModelPresentation presentation = getConfiguredPresentation(element);
+		if (presentation instanceof IColorProvider) {
+			IColorProvider colorProvider = (IColorProvider) presentation;
+			return colorProvider.getForeground(element);
+		}
+		return null;
+	}
 
-    @Override
+	@Override
 	public Color getBackground(Object element) {
-        IDebugModelPresentation presentation = getConfiguredPresentation(element);
-        if (presentation instanceof IColorProvider) {
-            IColorProvider colorProvider = (IColorProvider) presentation;
-            return colorProvider.getBackground(element);
-        }
-        return null;
-    }
+		IDebugModelPresentation presentation = getConfiguredPresentation(element);
+		if (presentation instanceof IColorProvider) {
+			IColorProvider colorProvider = (IColorProvider) presentation;
+			return colorProvider.getBackground(element);
+		}
+		return null;
+	}
 
-    @Override
+	@Override
 	public Font getFont(Object element) {
-        IDebugModelPresentation presentation = getConfiguredPresentation(element);
-        if (presentation instanceof IFontProvider) {
-            IFontProvider fontProvider = (IFontProvider) presentation;
-            return fontProvider.getFont(element);
-        }
-        return null;
-    }
+		IDebugModelPresentation presentation = getConfiguredPresentation(element);
+		if (presentation instanceof IFontProvider) {
+			IFontProvider fontProvider = (IFontProvider) presentation;
+			return fontProvider.getFont(element);
+		}
+		return null;
+	}
 
 	@Override
 	public Annotation getInstructionPointerAnnotation(IEditorPart editorPart, IStackFrame frame) {
@@ -371,7 +369,7 @@ public class DelegatingModelPresentation implements IDebugModelPresentation, IDe
 			}
 		}
 		if (annotation == null) {
-            boolean defaultAnnotation = id == null;
+			boolean defaultAnnotation = id == null;
 			if (id == null || text == null || (defaultAnnotation && image == null)) {
 				IThread thread = frame.getThread();
 				IStackFrame tos = null;
