@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2013 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,16 +10,20 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Paul Pazderski - Bug 251642: show process termination time
  *******************************************************************************/
 package org.eclipse.debug.internal.ui.preferences;
 
 
+import java.text.DateFormat;
 import java.text.ParseException;
 import java.util.Arrays;
 import java.util.Date;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
+import org.eclipse.core.runtime.Adapters;
+import org.eclipse.core.runtime.IAdaptable;
 import org.eclipse.debug.core.DebugPlugin;
 import org.eclipse.debug.core.model.IDebugElement;
 import org.eclipse.debug.core.model.IProcess;
@@ -27,8 +31,6 @@ import org.eclipse.debug.internal.ui.IDebugHelpContextIds;
 import org.eclipse.debug.internal.ui.SWTFactory;
 import org.eclipse.jface.resource.JFaceResources;
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.custom.BidiSegmentEvent;
-import org.eclipse.swt.custom.BidiSegmentListener;
 import org.eclipse.swt.custom.StyledText;
 import org.eclipse.swt.graphics.Font;
 import org.eclipse.swt.layout.GridData;
@@ -38,8 +40,6 @@ import org.eclipse.swt.widgets.Text;
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.dialogs.PropertyPage;
 
-import com.ibm.icu.text.DateFormat;
-
 public class ProcessPropertyPage extends PropertyPage {
 
 	private static Font fHeadingFont = JFaceResources.getFontRegistry().getBold(JFaceResources.DIALOG_FONT);
@@ -58,12 +58,21 @@ public class ProcessPropertyPage extends PropertyPage {
 
 		IProcess proc = getProcess();
 
-	//create the process time section
+		// create the process launch time section
 		SWTFactory.createLabel(parent, DebugPreferencesMessages.ProcessPropertyPage_0, fHeadingFont, 1);
 		Text text = SWTFactory.createText(parent, SWT.READ_ONLY, 1);
 		((GridData)text.getLayoutData()).horizontalIndent = 10;
 		PlatformUI.getWorkbench().getHelpSystem().setHelp(text, IDebugHelpContextIds.PROCESS_PAGE_RUN_AT);
-		text.setText(getTimeText(proc));
+		text.setText(getLaunchTimeText(proc));
+		text.setBackground(parent.getBackground());
+		SWTFactory.createVerticalSpacer(parent, 2);
+
+		// create the process terminate time section
+		SWTFactory.createLabel(parent, DebugPreferencesMessages.ProcessPropertyPage_10, fHeadingFont, 1);
+		text = SWTFactory.createText(parent, SWT.READ_ONLY, 1);
+		((GridData) text.getLayoutData()).horizontalIndent = 10;
+		PlatformUI.getWorkbench().getHelpSystem().setHelp(text, IDebugHelpContextIds.PROCESS_PAGE_TERMINATE_AT);
+		text.setText(getTerminateTimeText(proc));
 		text.setBackground(parent.getBackground());
 		SWTFactory.createVerticalSpacer(parent, 2);
 
@@ -103,34 +112,31 @@ public class ProcessPropertyPage extends PropertyPage {
 				final int[] segments = new int[count - 1];
 				commandLineText = DebugPlugin.renderArguments(arguments, segments);
 
-				styledText.addBidiSegmentListener(new BidiSegmentListener() {
-					@Override
-					public void lineGetSegments(BidiSegmentEvent event) {
-						int offset = event.lineOffset;
-						int end = offset + event.lineText.length();
+				styledText.addBidiSegmentListener(event -> {
+					int offset = event.lineOffset;
+					int end = offset + event.lineText.length();
 
-						// extract segments for the current line:
-						int iStart = Arrays.binarySearch(segments, offset);
-						if (iStart < 0) {
-							iStart = -iStart - 1;
-						}
-						int i = iStart;
-						while (i < segments.length && segments[i] < end) {
-							i++;
-						}
-						int n = i - iStart;
-						if (n > 0) {
-							if (n == segments.length) {
-								event.segments = segments;
-							} else {
-								int[] lineSegments = new int[n];
-								System.arraycopy(segments, iStart, lineSegments, 0, n);
-								event.segments = lineSegments;
-							}
-							final char[] chars = new char[n];
-							Arrays.fill(chars, '\n');
-							event.segmentsChars = chars;
+					// extract segments for the current line:
+					int iStart = Arrays.binarySearch(segments, offset);
+					if (iStart < 0) {
+						iStart = -iStart - 1;
+					}
+					int i = iStart;
+					while (i < segments.length && segments[i] < end) {
+						i++;
+					}
+					int n = i - iStart;
+					if (n > 0) {
+						if (n == segments.length) {
+							event.segments = segments;
+						} else {
+							int[] lineSegments = new int[n];
+							System.arraycopy(segments, iStart, lineSegments, 0, n);
+							event.segments = lineSegments;
 						}
+						final char[] chars = new char[n];
+						Arrays.fill(chars, '\n');
+						event.segmentsChars = chars;
 					}
 				});
 			}
@@ -157,20 +163,29 @@ public class ProcessPropertyPage extends PropertyPage {
 
 	/**
 	 * Gets the process from the selected element
-	 * @return the process or null if the element is not a process
+	 *
+	 * @return the process or null if the element does not implement or adapt
+	 *         IProcess
 	 *
 	 * @since 3.2
 	 */
 	private IProcess getProcess() {
-		IProcess proc = null;
-		Object obj = getElement();
-		if (obj instanceof IDebugElement) {
-			obj = ((IDebugElement)obj).getDebugTarget().getProcess();
+		IAdaptable element = getElement();
+		if (element instanceof IProcess) {
+			return ((IProcess) element);
 		}
-		if (obj instanceof IProcess) {
-			proc = ((IProcess)obj);
+		if (element instanceof IDebugElement) {
+			return ((IDebugElement)element).getDebugTarget().getProcess();
 		}
-		return proc;
+		Object adapted = Adapters.adapt(element, IProcess.class, true);
+		if (adapted != null) {
+			return ((IProcess) adapted);
+		}
+		adapted = Adapters.adapt(element, IDebugElement.class, true);
+		if (adapted != null) {
+			return ((IDebugElement) adapted).getDebugTarget().getProcess();
+		}
+		return null;
 	}
 
 	/**
@@ -189,7 +204,9 @@ public class ProcessPropertyPage extends PropertyPage {
 				return tmp;
 			}
 			tmp = proc.getLabel();
-			int idx = tmp.lastIndexOf("("); //$NON-NLS-1$
+			// TODO remove this ugly workaround after removing start time from process label
+			// in jdt
+			int idx = tmp.lastIndexOf('(');
 			if(idx < 0) {
 				idx = tmp.length();
 			}
@@ -199,44 +216,70 @@ public class ProcessPropertyPage extends PropertyPage {
 	}
 
 	/**
-	 * gets the pattern of text from the process label specified by RegEx
-	 * @param proc the process to compile the RegEx against
-	 * @param deftext the default text to return if the process is null
-	 * @param regex the RegEx to match in the process label
-	 * @return the RegEx matched text or the default supplied text if the process is null
+	 * Try to get the launch time for the process.
 	 *
-	 * @see DebugPlugin#ATTR_RUN_AT_TIME
+	 * @param proc the process to get launch time for
+	 * @return the launch time or default replacement
 	 * @since 3.2
 	 */
-	private String getTimeText(IProcess proc) {
-		String text = DebugPreferencesMessages.ProcessPropertyPage_4;
-		if(proc != null) {
-			String tmp = proc.getAttribute(DebugPlugin.ATTR_LAUNCH_TIMESTAMP);
-			if(tmp != null) {
-				//check to see if the date/time is just the raw long (as a string)
-				try {
-					long l = Long.parseLong(tmp);
-					return DateFormat.getDateTimeInstance(DateFormat.MEDIUM, DateFormat.MEDIUM).format(new Date(l));
-				}
-				catch(NumberFormatException nfe) {
-					//not a number try to format the string so it always looks the same
-					try {
-						Date fdate = DateFormat.getInstance().parse(tmp);
-						return DateFormat.getDateTimeInstance(DateFormat.MEDIUM, DateFormat.MEDIUM).format(fdate);
-					}
-					catch(ParseException pe) {
-						//couldn't do it, return the raw string
-					}
-				}
-				return tmp;
-			}
-			Pattern pattern = Pattern.compile("\\(.*\\)"); //$NON-NLS-1$
-			Matcher matcher = pattern.matcher(proc.getLabel());
-			if(matcher.find()) {
-				text = matcher.group(0);
+	private String getLaunchTimeText(IProcess proc) {
+		String text = getTimeFromAttribute(proc, DebugPlugin.ATTR_LAUNCH_TIMESTAMP);
+		if (text != null) {
+			return text;
+		}
+		// TODO remove this parsing when launch time is no fixed part of label anymore
+		Pattern pattern = Pattern.compile("\\(.*\\)"); //$NON-NLS-1$
+		Matcher matcher = pattern.matcher(proc.getLabel());
+		if (matcher.find()) {
+			text = matcher.group(0);
+		}
+		if (text != null) {
+			return text;
+		}
+		return DebugPreferencesMessages.ProcessPropertyPage_4;
+	}
+
+	/**
+	 * Try to get the terminate time for the process.
+	 *
+	 * @param proc the process to get terminate time for
+	 * @return the terminate time or default replacement
+	 */
+	private String getTerminateTimeText(IProcess proc) {
+		String text = getTimeFromAttribute(proc, DebugPlugin.ATTR_TERMINATE_TIMESTAMP);
+		return text != null ? text : DebugPreferencesMessages.ProcessPropertyPage_4;
+	}
+
+	/**
+	 * Try to process launch timestamp attribute.
+	 *
+	 * @param proc the process to check
+	 * @param attr the process attribute to check for timestamp
+	 * @return the timestamp string or <code>null</code>
+	 * @since 3.2
+	 */
+	private String getTimeFromAttribute(IProcess proc, String attr) {
+		if (proc == null || attr == null) {
+			return null;
+		}
+		String time = proc.getAttribute(attr);
+		if (time == null) {
+			return null;
+		}
+		// check to see if the date/time is just the raw long (as a string)
+		try {
+			long l = Long.parseLong(time);
+			return DateFormat.getDateTimeInstance(DateFormat.MEDIUM, DateFormat.MEDIUM).format(new Date(l));
+		} catch (NumberFormatException nfe) {
+			// not a number try to format the string so it always looks the same
+			try {
+				Date fdate = DateFormat.getInstance().parse(time);
+				return DateFormat.getDateTimeInstance(DateFormat.MEDIUM, DateFormat.MEDIUM).format(fdate);
+			} catch (ParseException pe) {
+				// couldn't do it, return the raw string
 			}
 		}
-		return text;
+		return time;
 	}
 
 	/**
