@@ -18,16 +18,14 @@ import java.io.File;
 
 import org.eclipse.debug.internal.core.IInternalDebugCoreConstants;
 import org.eclipse.debug.internal.ui.DebugPluginImages;
-import org.eclipse.debug.internal.ui.DebugUIPlugin;
 import org.eclipse.debug.internal.ui.IDebugHelpContextIds;
 import org.eclipse.debug.internal.ui.IInternalDebugUIConstants;
 import org.eclipse.debug.internal.ui.sourcelookup.SourceLookupUIMessages;
 import org.eclipse.jface.dialogs.IDialogConstants;
+import org.eclipse.jface.dialogs.IDialogSettings;
 import org.eclipse.jface.dialogs.TitleAreaDialog;
 import org.eclipse.jface.resource.JFaceResources;
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.events.ModifyEvent;
-import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.graphics.Font;
@@ -43,6 +41,7 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 import org.eclipse.ui.PlatformUI;
+import org.osgi.framework.FrameworkUtil;
 
 /**
  * The dialog for selecting the external folder for which a source container will be created.
@@ -68,7 +67,9 @@ public class DirectorySourceContainerDialog extends TitleAreaDialog {
 	 * @param shell shell
 	 */
 	public DirectorySourceContainerDialog(Shell shell) {
-		this(shell, IInternalDebugCoreConstants.EMPTY_STRING, DebugUIPlugin.getDefault().getDialogSettings().getBoolean(LAST_SUBDIR_SETTING));
+		this(shell, IInternalDebugCoreConstants.EMPTY_STRING,
+				PlatformUI.getDialogSettingsProvider(FrameworkUtil.getBundle(DirectorySourceContainerDialog.class))
+						.getDialogSettings().getBoolean(LAST_SUBDIR_SETTING));
 		fNewContainer = true;
 	}
 
@@ -124,50 +125,45 @@ public class DirectorySourceContainerDialog extends TitleAreaDialog {
 		composite.setLayoutData(new GridData(GridData.FILL_BOTH));
 		composite.setFont(font);
 
-        Composite dirComposite = new Composite(composite, SWT.NONE);
-        layout = new GridLayout(2, false);
+		Composite dirComposite = new Composite(composite, SWT.NONE);
+		layout = new GridLayout(2, false);
 		dirComposite.setLayout(layout);
 		dirComposite.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
 		dirComposite.setFont(font);
 
-        Label label = new Label(dirComposite, SWT.NONE);
-        label.setText(SourceLookupUIMessages.DirectorySourceContainerDialog_4);
-        GridData data = new GridData(GridData.FILL_HORIZONTAL);
-        data.horizontalSpan = 2;
-        label.setLayoutData(data);
-        label.setFont(font);
+		Label label = new Label(dirComposite, SWT.NONE);
+		label.setText(SourceLookupUIMessages.DirectorySourceContainerDialog_4);
+		GridData data = new GridData(GridData.FILL_HORIZONTAL);
+		data.horizontalSpan = 2;
+		label.setLayoutData(data);
+		label.setFont(font);
 
-        fDirText = new Text(dirComposite, SWT.BORDER);
-        data = new GridData(GridData.FILL_HORIZONTAL);
-        data.horizontalSpan = 1;
-        fDirText.setLayoutData(data);
-        fDirText.setFont(font);
-        fDirText.addModifyListener(new ModifyListener() {
+		fDirText = new Text(dirComposite, SWT.BORDER);
+		data = new GridData(GridData.FILL_HORIZONTAL);
+		data.horizontalSpan = 1;
+		fDirText.setLayoutData(data);
+		fDirText.setFont(font);
+		fDirText.addModifyListener(e -> validate());
+
+		Button button = new Button(dirComposite, SWT.PUSH);
+		button.setText(SourceLookupUIMessages.DirectorySourceContainerDialog_5);
+		data = new GridData();
+		int widthHint = convertHorizontalDLUsToPixels(IDialogConstants.BUTTON_WIDTH);
+		Point minSize = button.computeSize(SWT.DEFAULT, SWT.DEFAULT, true);
+		data.widthHint = Math.max(widthHint, minSize.x);
+		button.setLayoutData(data);
+		button.setFont(JFaceResources.getDialogFont());
+		button.addSelectionListener(new SelectionAdapter() {
 			@Override
-			public void modifyText( ModifyEvent e ) {
-				validate();
-			}
-        });
-
-        Button button = new Button(dirComposite, SWT.PUSH);
-        button.setText(SourceLookupUIMessages.DirectorySourceContainerDialog_5);
-        data = new GridData();
-        int widthHint = convertHorizontalDLUsToPixels(IDialogConstants.BUTTON_WIDTH);
-        Point minSize = button.computeSize(SWT.DEFAULT, SWT.DEFAULT, true);
-        data.widthHint = Math.max(widthHint, minSize.x);
-        button.setLayoutData(data);
-        button.setFont(JFaceResources.getDialogFont());
-        button.addSelectionListener(new SelectionAdapter() {
-            @Override
 			public void widgetSelected(SelectionEvent event) {
-            	browse();
-            }
-        });
+				browse();
+			}
+		});
 
-        fSubfoldersButton = new Button(composite, SWT.CHECK);
-        fSubfoldersButton.setText(SourceLookupUIMessages.DirectorySourceContainerDialog_6);
+		fSubfoldersButton = new Button(composite, SWT.CHECK);
+		fSubfoldersButton.setText(SourceLookupUIMessages.DirectorySourceContainerDialog_6);
 
-        return parentComposite;
+		return parentComposite;
 	}
 
 	@Override
@@ -196,15 +192,21 @@ public class DirectorySourceContainerDialog extends TitleAreaDialog {
 	protected void okPressed() {
 		fDirectory = fDirText.getText().trim();
 		fSearchSubfolders = fSubfoldersButton.getSelection();
-		DebugUIPlugin.getDefault().getDialogSettings().put(LAST_PATH_SETTING, fDirectory);
-		DebugUIPlugin.getDefault().getDialogSettings().put(LAST_SUBDIR_SETTING, fSearchSubfolders);
+		IDialogSettings dialogSettings = PlatformUI
+				.getDialogSettingsProvider(FrameworkUtil.getBundle(DirectorySourceContainerDialog.class))
+				.getDialogSettings();
+		dialogSettings.put(LAST_PATH_SETTING, fDirectory);
+		dialogSettings.put(LAST_SUBDIR_SETTING, fSearchSubfolders);
 		super.okPressed();
 	}
 
 	private void browse() {
 		String last = fDirText.getText().trim();
 		if (last.length() == 0) {
-			last = DebugUIPlugin.getDefault().getDialogSettings().get(LAST_PATH_SETTING);
+			IDialogSettings dialogSettings = PlatformUI
+					.getDialogSettingsProvider(FrameworkUtil.getBundle(DirectorySourceContainerDialog.class))
+					.getDialogSettings();
+			last = dialogSettings.get(LAST_PATH_SETTING);
 		}
 		if (last == null) {
 			last = IInternalDebugCoreConstants.EMPTY_STRING;
