@@ -34,18 +34,14 @@ public class HexRendering extends AbstractAsyncTableRendering {
 	@Override
 	public String getString(String dataType, BigInteger address,
 			MemoryByte[] data) {
-		StringBuffer strBuffer = new StringBuffer();
+		StringBuilder strBuffer = new StringBuilder();
 
 		String paddedStr = DebugUIPlugin.getDefault().getPreferenceStore().getString(IDebugUIConstants.PREF_PADDED_STR);
 
-		for (int i=0; i<data.length; i++)
-		{
-			if (data[i].isReadable())
-			{
-				strBuffer.append(new String(RenderingsUtil.convertByteToCharArray(data[i].getValue())));
-			}
-			else
-			{
+		for (MemoryByte memByte : data) {
+			if (memByte.isReadable()) {
+				strBuffer.append(new String(RenderingsUtil.convertByteToCharArray(memByte.getValue())));
+			} else {
 				// pad with padded string
 				strBuffer.append(paddedStr);
 			}
