@@ -16,6 +16,7 @@
  *******************************************************************************/
 package org.eclipse.debug.internal.ui.views.variables.details;
 
+import java.text.MessageFormat;
 import java.util.Iterator;
 import java.util.ResourceBundle;
 
@@ -51,7 +52,6 @@ import org.eclipse.debug.ui.IDebugView;
 import org.eclipse.debug.ui.IDetailPane2;
 import org.eclipse.debug.ui.IValueDetailListener;
 import org.eclipse.jface.action.IAction;
-import org.eclipse.jface.action.IMenuListener;
 import org.eclipse.jface.action.IMenuManager;
 import org.eclipse.jface.action.IStatusLineManager;
 import org.eclipse.jface.action.MenuManager;
@@ -76,14 +76,10 @@ import org.eclipse.jface.text.source.SourceViewer;
 import org.eclipse.jface.text.source.SourceViewerConfiguration;
 import org.eclipse.jface.util.IPropertyChangeListener;
 import org.eclipse.jface.util.PropertyChangeEvent;
-import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.ISelectionProvider;
 import org.eclipse.jface.viewers.IStructuredSelection;
-import org.eclipse.jface.viewers.SelectionChangedEvent;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.StyledText;
-import org.eclipse.swt.events.DisposeEvent;
-import org.eclipse.swt.events.DisposeListener;
 import org.eclipse.swt.events.FocusAdapter;
 import org.eclipse.swt.events.FocusEvent;
 import org.eclipse.swt.events.KeyEvent;
@@ -114,8 +110,6 @@ import org.eclipse.ui.texteditor.IAbstractTextEditorHelpContextIds;
 import org.eclipse.ui.texteditor.ITextEditorActionConstants;
 import org.eclipse.ui.texteditor.ITextEditorActionDefinitionIds;
 
-import com.ibm.icu.text.MessageFormat;
-
 /**
  * This detail pane uses a source viewer to display detailed information about the current
  * selection.  It incorporates a large number of actions into its context menu.  It is the
@@ -214,15 +208,15 @@ public class DefaultDetailPane extends AbstractDetailPane implements IDetailPane
 					message = bp.getMarker().getAttribute(IMarker.MESSAGE, ""); //$NON-NLS-1$
 				} else if (element instanceof IBreakpointContainer) {
 					IBreakpointContainer c = (IBreakpointContainer) element;
-		            IAdaptable category = c.getCategory();
-		            if (category != null) {
-			            IWorkbenchAdapter adapter = category.getAdapter(IWorkbenchAdapter.class);
-			            if (adapter != null) {
-			                message = adapter.getLabel(category);
-			            } else {
-			            	message = c.getOrganizer().getLabel();
-			            }
-		            }
+					IAdaptable category = c.getCategory();
+					if (category != null) {
+						IWorkbenchAdapter adapter = category.getAdapter(IWorkbenchAdapter.class);
+						if (adapter != null) {
+							message = adapter.getLabel(category);
+						} else {
+							message = c.getOrganizer().getLabel();
+						}
+					}
 				}
 				// When selecting a index partition, clear the pane
 				if (val instanceof IndexedValuePartition) {
@@ -236,10 +230,13 @@ public class DefaultDetailPane extends AbstractDetailPane implements IDetailPane
 					fModel.computeDetail(val, this);
 					synchronized (this) {
 						try {
-							// wait for a max of 30 seconds for result, then cancel
-							wait(30000);
+							// detail could already computed at this point (see bug 252433)
 							if (!fComputed) {
-								fMonitor.setCanceled(true);
+								// wait for a max of 30 seconds for result, then cancel
+								wait(30000);
+								if (!fComputed) {
+									fMonitor.setCanceled(true);
+								}
 							}
 						} catch (InterruptedException e) {
 							break;
@@ -469,14 +466,10 @@ public class DefaultDetailPane extends AbstractDetailPane implements IDetailPane
 
 	private void installWhitespacePreferenceListener() {
 		IPreferenceStore store = EditorsUI.getPreferenceStore();
-		fPreferenceStorePropertyChangeListener = new IPropertyChangeListener() {
-
-			@Override
-			public void propertyChange(PropertyChangeEvent event) {
-				String property = event.getProperty();
-				if (AbstractTextEditor.PREFERENCE_SHOW_WHITESPACE_CHARACTERS.equals(property)) {
-					toggleWhitespaceCharacterPainter();
-				}
+		fPreferenceStorePropertyChangeListener = event -> {
+			String property = event.getProperty();
+			if (AbstractTextEditor.PREFERENCE_SHOW_WHITESPACE_CHARACTERS.equals(property)) {
+				toggleWhitespaceCharacterPainter();
 			}
 		};
 		store.addPropertyChangeListener(fPreferenceStorePropertyChangeListener);
@@ -532,12 +525,7 @@ public class DefaultDetailPane extends AbstractDetailPane implements IDetailPane
 		});
 
 		// Add the selection listener so selection dependent actions get updated.
-		fSourceViewer.getSelectionProvider().addSelectionChangedListener(new ISelectionChangedListener() {
-			@Override
-			public void selectionChanged(SelectionChangedEvent event) {
-				updateSelectionDependentActions();
-			}
-		});
+		fSourceViewer.getSelectionProvider().addSelectionChangedListener(event -> updateSelectionDependentActions());
 
 		// Add a focus listener to update actions when details area gains focus
 		fSourceViewer.getControl().addFocusListener(new FocusAdapter() {
@@ -576,20 +564,17 @@ public class DefaultDetailPane extends AbstractDetailPane implements IDetailPane
 
 		// disposed controls don't get a FocusOut event, make sure all actions
 		// have been deactivated
-		fSourceViewer.getControl().addDisposeListener(new DisposeListener() {
-			@Override
-			public void widgetDisposed(DisposeEvent e) {
-				if (fHasFocus) {
-					setGlobalAction(IDebugView.SELECT_ALL_ACTION, null);
-					setGlobalAction(IDebugView.CUT_ACTION, null);
-					setGlobalAction(IDebugView.COPY_ACTION, null);
-					setGlobalAction(IDebugView.PASTE_ACTION, null);
-					setGlobalAction(IDebugView.FIND_ACTION, null);
-					setGlobalAction(getAction(DETAIL_ASSIGN_VALUE_ACTION)
-							.getActionDefinitionId(), null);
-					setGlobalAction(getAction(DETAIL_CONTENT_ASSIST_ACTION)
-							.getActionDefinitionId(), null);
-				}
+		fSourceViewer.getControl().addDisposeListener(e -> {
+			if (fHasFocus) {
+				setGlobalAction(IDebugView.SELECT_ALL_ACTION, null);
+				setGlobalAction(IDebugView.CUT_ACTION, null);
+				setGlobalAction(IDebugView.COPY_ACTION, null);
+				setGlobalAction(IDebugView.PASTE_ACTION, null);
+				setGlobalAction(IDebugView.FIND_ACTION, null);
+				setGlobalAction(getAction(DETAIL_ASSIGN_VALUE_ACTION)
+						.getActionDefinitionId(), null);
+				setGlobalAction(getAction(DETAIL_CONTENT_ASSIST_ACTION)
+						.getActionDefinitionId(), null);
 			}
 		});
 
@@ -617,9 +602,9 @@ public class DefaultDetailPane extends AbstractDetailPane implements IDetailPane
 		textAction.setDisabledImageDescriptor(DebugPluginImages.getImageDescriptor(IDebugUIConstants.IMG_DLCL_CONTENT_ASSIST));
 		PlatformUI.getWorkbench().getHelpSystem().setHelp(textAction, IDebugHelpContextIds.DETAIL_PANE_CONTENT_ASSIST_ACTION);
 		ActionHandler actionHandler = new ActionHandler(textAction);
-        IHandlerService handlerService = getViewSite().getService(IHandlerService.class);
-        fContentAssistActivation = handlerService.activateHandler(textAction.getActionDefinitionId(), actionHandler);
-        setAction(DETAIL_CONTENT_ASSIST_ACTION, textAction);
+		IHandlerService handlerService = getViewSite().getService(IHandlerService.class);
+		fContentAssistActivation = handlerService.activateHandler(textAction.getActionDefinitionId(), actionHandler);
+		setAction(DETAIL_CONTENT_ASSIST_ACTION, textAction);
 
 		textAction= new TextViewerAction(fSourceViewer, ITextOperationTarget.SELECT_ALL);
 		textAction.configureAction(DetailMessages.DefaultDetailPane_Select__All_5, IInternalDebugCoreConstants.EMPTY_STRING,IInternalDebugCoreConstants.EMPTY_STRING);
@@ -678,12 +663,7 @@ public class DefaultDetailPane extends AbstractDetailPane implements IDetailPane
 	protected void createDetailContextMenu(Control menuControl) {
 		MenuManager menuMgr= new MenuManager();
 		menuMgr.setRemoveAllWhenShown(true);
-		menuMgr.addMenuListener(new IMenuListener() {
-			@Override
-			public void menuAboutToShow(IMenuManager mgr) {
-				fillDetailContextMenu(mgr);
-			}
-		});
+		menuMgr.addMenuListener(this::fillDetailContextMenu);
 		Menu menu= menuMgr.createContextMenu(menuControl);
 		menuControl.setMenu(menu);
 
@@ -751,13 +731,13 @@ public class DefaultDetailPane extends AbstractDetailPane implements IDetailPane
 			}
 		}
 
-        synchronized (this) {
-        	if (fDetailJob != null) {
-        		fDetailJob.cancel();
-        	}
+		synchronized (this) {
+			if (fDetailJob != null) {
+				fDetailJob.cancel();
+			}
 			fDetailJob = new DetailJob(selection,fModelPresentation);
 			fDetailJob.schedule();
-        }
+		}
 
 	}
 
@@ -792,8 +772,8 @@ public class DefaultDetailPane extends AbstractDetailPane implements IDetailPane
 			}
 			if (fContentAssistActivation != null){
 				IHandlerService service = getViewSite().getService(IHandlerService.class);
-		        service.deactivateHandler(fContentAssistActivation);
-		        fContentAssistActivation = null;
+				service.deactivateHandler(fContentAssistActivation);
+				fContentAssistActivation = null;
 			}
 
 			disposeUndoRedoAction(ITextEditorActionConstants.UNDO);
@@ -873,12 +853,12 @@ public class DefaultDetailPane extends AbstractDetailPane implements IDetailPane
 			}
 		}
 
-	    if (svc == null) {
+		if (svc == null) {
 			svc = new SourceViewerConfiguration();
 			fSourceViewer.setEditable(false);
 		}
-	    fSourceViewer.unconfigure();
-	    fSourceViewer.configure(svc);
+		fSourceViewer.unconfigure();
+		fSourceViewer.configure(svc);
 		//update actions that depend on the configuration of the source viewer
 
 		if (isInView()){
