@@ -16,7 +16,6 @@ package org.eclipse.debug.ui;
 import java.util.List;
 
 import org.eclipse.core.runtime.CoreException;
-import org.eclipse.core.runtime.Platform;
 import org.eclipse.core.runtime.preferences.IEclipsePreferences;
 import org.eclipse.core.runtime.preferences.InstanceScope;
 import org.eclipse.debug.core.DebugPlugin;
@@ -52,7 +51,6 @@ import org.eclipse.swt.widgets.Control;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Tree;
-import org.eclipse.swt.widgets.TreeItem;
 import org.eclipse.ui.IViewPart;
 import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.IWorkbenchPartSite;
@@ -170,13 +168,6 @@ public class InspectPopupDialog extends DebugPopup {
 		});
 		fViewer.setInput(treeRoot);
 
-		// Workaround for empty inspect dialog due to Mac bug (Bug 567787)
-		if (Platform.OS_MACOSX.equals(Platform.getOS())) {
-			fTree.setItemCount(1);
-			TreeItem item = fTree.getItem(0);
-			item.getText();
-		}
-
 		return fTree;
 	}
 
